/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-21 17:23:32
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-09-02 16:22:53
 * @FilePath: \Game-Backstage-Management-System\src\hooks\useDialog.ts
 * @Description:
 *
 */
import type { DialogSetting } from '@/types/table'
import type { FormInstance } from 'element-plus'
import { useRequest } from './useRequest'
import axiosInstance from '@/utils/axios/axiosInstance'
import { ElMessage, ElMessageBox } from 'element-plus'
import { nextTick } from 'vue'
import 'element-plus/theme-chalk/el-message.css'
import 'element-plus/theme-chalk/el-message-box.css'

const { analysisResCode } = useRequest()

export function useDialog() {
  // 对话框关闭
  const dialogClose = (formEl: FormInstance | undefined, dialogConfig: DialogSetting) => {
    if (!formEl) return

    dialogConfig.dialogVisible = false
    formEl.resetFields()
  }

  // 对话框提交
  const submitDialog = (
    formEl: FormInstance | undefined,
    dialogConfig: DialogSetting,
    url: string,
    formData: any
  ) => {
    return new Promise((reslove, reject) => {
      ElMessageBox.confirm('确认提交吗？', '警告', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(() => {
          try {
            if (!formEl) {
              reject(new Error('no formEl'))
              return
            }
            formEl.validate(async (valid, field) => {
              if (valid) {
                let result = await axiosInstance.post(url, formData)
                let info = JSON.parse(JSON.stringify(result))

                analysisResCode(info)
                  .then(() => {
                    dialogConfig.dialogVisible = false
                    reslove(true)
                  })
                  .catch((err) => {
                    reject(err)
                    console.log(err)
                  })
              } else {
                console.log(field)
                console.log('表单校验不通过')
              }
            })
          } catch (err) {
            console.log(err)
            ElMessage({
              type: 'error',
              message: '未知错误'
            })
            throw new Error('other err')
          }
        })
        .catch(() => {
          reject(false)
        })
    })
  }

  // 修改按钮
  const handleEdit = (row: any, formData: any, dialogConfig: DialogSetting) => {
    dialogConfig.type = 1
    dialogConfig.dialogVisible = true

    // 这里放到nextTick，因为resetFields原理是将表单重置到dom刚渲染时的数据
    // 而这个表单，如果第一次使用就点击编辑的话，会将初始值直接设置为这行的数据，导致无法重置
    nextTick(() => {
      for (const key in row) {
        if (key in formData) {
          formData[key] = row[key]
        } else {
          console.log(key)
        }
      }
    })
    console.log(dialogConfig)
    // throw new Error('test')
  }

  const addNeweItem = (dialogConfig: DialogSetting) => {
    dialogConfig.type = 0
    dialogConfig.dialogVisible = true
  }

  return {
    dialogClose,
    submitDialog,
    handleEdit,
    addNeweItem
  }
}
