/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-23 14:58:29
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-09-02 15:23:17
 * @FilePath: \Game-Backstage-Management-System\src\types\dataAnalysis.ts
 * @Description:用于dataAnalysis相关组件的type
 *
 */

// 下拉选项的信息
export interface DropDownItem {
  value: any
  label: string
}

// 下拉框所需要的props信息
export interface DropDownInfo {
  size?: string
  defaultSelect: any
  title: string
  optionsList: Array<DropDownItem>
}

/**
 * @description: 数据展示组件的请求配置
 *
 * @return {*}
 */
export interface ReqConfig {
  url: string
  otherOptions: any
}

// 数据展示的字段信息
export interface StaticField {
  name: string
  cnName: string
  value: any // 值
  compareVal?: any
}

// 数据分析页面头部数据所需要的props
// 其中如果配置了请求参数，那么会使用url去查询，然后赋值
// 如果没有则直接使用fieldinfo里的value
export interface StaticDataInfo {
  requestConfig?: ReqConfig // 请求参数配置
  fieldsInfo: Array<StaticField> //字段信息
  titleClass?: string // 标题的样式
  valueClass?: string // 值的样式
}

// 时间趋势图的tab信息
export interface TabInfo {
  name: string // tab的字段
  tabTitle: string // tab的标题
  type: number // 到时候需要获取数据的url
}

/**
 * @description: 图表所需要的props,其中的legnedData毓seriesData的length要一致
 *              series中的name依赖毓lengdata
 * @return {*}
 */
export interface OptionsProps {
  xAxisData: Array<any> // x轴的刻度lable
  legendData: Array<any> // 图例的信息
  seriesData: Array<any> // 数据
}

// 返回的数据中每个字段的分类信息
export interface ResDataFieldInfo {
  xAxis: string // x轴的刻度信息所在的字段
  values: Array<string> // 值所在的字段
}

// 表格字段
// key需要与上方的resDataField的values字段对应
export interface TrendTableField {
  [key: string]: string
}

// 时间趋势组件所需要的props
export interface TemporalTrendProps {
  waitTimeSelect: boolean // 是否需要等待时间组件选择完成后请求

  tabInfo?: Array<TabInfo> // 用于切换的tab的信息

  type: number // 趋势组件的类型，1为小时段，2为日期统计
  needChangeExpress: boolean // 是否需要切换表格/图表
  selectExpressForm: number // 默认的表现形式，1为图表，2为表格

  needTable: boolean // 是否需要表格
  tableFieldsInfo: TrendTableField // 表格的字段信息

  needCharts: boolean // 是否需要图表

  resDataFieldsInfo: ResDataFieldInfo // 返回的数据中每个字段的分类信息
  requestConfig: ReqConfig // 请求参数配置，需要监听，一旦变化，需要重新获取数据

  staticFields?: Array<StaticField> // 图表中统计组件的字段信息
  title: string // 上方显示的title
}

// 头部切换组件所需要的props
export interface HeaderCardProps {
  title: string // title信息
  defaultPf?: string // 默认选择的pf
  openDateSelect: boolean // 是否开启时间选择
}

// 趋势图组件需要的信息
export interface TemporalTrendInfo {
  dataReqConfig: ReqConfig // 请求的参数和配置
  resDataField: ResDataFieldInfo // 返回数据中的字段信息
  tabList?: Array<TabInfo> //表格数据
  trendTableFields: TrendTableField // 表格的字段，同时也作为legend的一部分
  chartsStaticField?: Array<StaticField> // 统计字段的信息
}
