/*
 * @Author: fxs bjnsfxs@163.com
 * @Date: 2024-08-26 15:46:42
 * @LastEditors: fxs bjnsfxs@163.com
 * @LastEditTime: 2024-08-30 15:45:41
 * @FilePath: \Game-Backstage-Management-System\src\utils\common\index.ts
 * @Description:
 *
 */
// 防抖
export function debounceFunc<T extends (...args: any[]) => any>(
  func: T,
  delay: number
): (...args: Parameters<T>) => void {
  let timer: ReturnType<typeof setTimeout> | null
  return (...args: Parameters<T>) => {
    if (timer) clearTimeout(timer)
    timer = setTimeout(() => {
      func(...args)
    }, delay)
  }
}

// 小数转百分比
export function decimalToPercentage(decimal: number, decimalPlaces: number = 0): string {
  // Convert the decimal to a percentage by multiplying by 100
  const percentage = decimal * 100

  // Format the percentage to a fixed number of decimal places
  const formattedPercentage = percentage.toFixed(decimalPlaces)

  // Append the '%' symbol and return the result
  return `${formattedPercentage}%`
}

// 生成时间刻度
export function generateHourlyArray(count: number) {
  const result = []
  for (let i = 0; i <= count; i++) {
    result.push(`${i}:00`)
  }
  return result
}

// 格式化时间，20240816=>2024-8-16
export function formatDate(dateString: string) {
  // 从字符串中提取年份、月份和日期
  const year = dateString.slice(0, 4)
  const month = dateString.slice(4, 6)
  const day = dateString.slice(6, 8)

  // 将月份和日期转换为整数以去除前导零
  const formattedMonth = parseInt(month, 10)
  const formattedDay = parseInt(day, 10)

  // 生成新的日期字符串
  return `${year}-${formattedMonth}-${formattedDay}`
}

// 将date对象转为yaer-month-day的格式
export function resetTimeToMidnight(dateTime: Date): string {
  // 创建一个 Date 对象来解析输入的日期时间字符串

  // 将时间部分设置为 00:00:00
  dateTime.setHours(0, 0, 0, 0)

  // 格式化日期为 'YYYY-MM-DD' 格式
  const year = dateTime.getFullYear()
  const month = String(dateTime.getMonth() + 1).padStart(2, '0') // 月份从0开始，需要加1
  const day = String(dateTime.getDate()).padStart(2, '0')

  // 返回格式化的字符串
  return `${year}-${month}-${day}`
}

/**
 * @description: 生成一个打包后可以使用的url
 * @param {string} url  传入一个assets文件夹下的文件名
 * @return {*}
 */
export const getAssetsImageUrl = (url: string) => {
  return new URL(`../../assets/${url}`, import.meta.url).href
}
